@@ -1,6 +1,8 @@
 import autopysta as ap
 import matplotlib.pyplot as pt
 from numpy import cos,sin
+from autopysta import AutopystaException
+#from exceptions import BaseException
 
 
 print(ap.version())
@@ -20,10 +22,10 @@ for i in range(1000):
     known_trajectory2.append(ap.point(i/10.0, 100 + i - 100*cos(i/100.), 10+10*sin(i/10.), 0.1, 1)) # tiempo, posicionX, vel, ac, pista
     
 try:
-    my_car = ap.vehicle(known_trajectory, 0.1)
-    my_car2 = ap.vehicle(known_trajectory2, 0.1)
-except ap.Exception as exc:
-    print (exc.code, exc.msg)
+    my_car = ap.vehicle(known_trajectory)
+    my_car2 = ap.vehicle(known_trajectory2)
+except BaseException as exc:
+    print (exc.args[0])
 #except RuntimeError as e:
 #    print e.args[0]
 
@@ -42,22 +44,22 @@ ccrr=[ap.fixed_demand_creator(ma, 0.5, 10), #20, 0, 10),
 #lcm = ap.no_lch()
 lcm  = ap.lcm_gipps()
 
+
+    #ERROR AS -0.1 us not valid
+    #Testing if I can get custom exceptions to work
+s = ap.simulation(lcm, 90, geo, ccrr, vv, -0.1)
+
 try:
-    s = ap.simulation(ma, lcm, 90, geo, ccrr, vv, 0.1)
-except ap.Exception as e:
-    print (e.code, e.msg)
-try:
-	r = s.run()
-except ap.Exception as exc:
-    print (exc.code, exc.msg)
-except (RuntimeError, e):
-    print (e.args[0])
-
-r.plotresults()     #plot all lane
-r.plotresults(1)    #plot certain lane
-r.plotresults(2)
-r.plotresults(3)
+    r = s.run()
+    r.plot_x_vs_t(1) #plot all lanes
+    r.plot_x_vs_t(2)
+    r.plot_x_vs_t(3)
+except AutopystaException as e:
+    print(e.args[0])
+except BaseException as e:
+    print("[BaseException]:", e.args[0])
 
+     
 
 
 
